==> vala-0.1.0.tar.bz2: vala-0.1.0/vala/valaliteralexpression.c <==
/* valaliteralexpression.vala
 *
 * Copyright (C) 2006-2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */
#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))

#include "valaliteralexpression.h"
#include <vala/valaliteral.h>
#include <vala/valasourcereference.h>
#include <vala/valaliteralexpression.h>
#include <vala/valacodevisitor.h>

struct _ValaLiteralExpressionPrivate {
	ValaLiteral* _literal;
};
#define VALA_LITERAL_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_LITERAL_EXPRESSION, ValaLiteralExpressionPrivate))
enum  {
	VALA_LITERAL_EXPRESSION_DUMMY_PROPERTY,
	VALA_LITERAL_EXPRESSION_LITERAL
};
static void vala_literal_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
static char* vala_literal_expression_real_to_string (ValaCodeNode* base);
static gpointer vala_literal_expression_parent_class = NULL;
static void vala_literal_expression_dispose (GObject * obj);


/**
 * Creates a new literal expression.
 *
 * @param literal a literal
 * @param source  reference to source code
 * @return        newly created literal expression
 */
ValaLiteralExpression* vala_literal_expression_new (ValaLiteral* _literal, ValaSourceReference* source)
{
	GParameter * __params;
	GParameter * __params_it;
	ValaLiteralExpression * self;
	g_return_val_if_fail (VALA_IS_LITERAL (_literal), NULL);
	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
	__params = g_new0 (GParameter, 2);
	__params_it = __params;
	(__params_it->name = "literal", g_value_init (&__params_it->value, VALA_TYPE_LITERAL), g_value_set_object (&__params_it->value, _literal), __params_it++);
	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
	self = g_object_newv (VALA_TYPE_LITERAL_EXPRESSION, __params_it - __params, __params);
	return self;
}


static void vala_literal_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
{
	ValaLiteralExpression * self;
	self = VALA_LITERAL_EXPRESSION (base);
	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
	vala_code_node_accept (VALA_CODE_NODE (vala_literal_expression_get_literal (self)), visitor);
	vala_code_visitor_visit_literal_expression (visitor, self);
}


static char* vala_literal_expression_real_to_string (ValaCodeNode* base)
{
	ValaLiteralExpression * self;
	self = VALA_LITERAL_EXPRESSION (base);
	return vala_code_node_to_string (VALA_CODE_NODE (vala_literal_expression_get_literal (self)));
}


ValaLiteral* vala_literal_expression_get_literal (ValaLiteralExpression* self)
{
	g_return_val_if_fail (VALA_IS_LITERAL_EXPRESSION (self), NULL);
	return self->priv->_literal;
}


void vala_literal_expression_set_literal (ValaLiteralExpression* self, ValaLiteral* value)
{
	ValaLiteral* __temp3;
	ValaLiteral* __temp2;
	g_return_if_fail (VALA_IS_LITERAL_EXPRESSION (self));
	__temp3 = NULL;
	__temp2 = NULL;
	self->priv->_literal = (__temp3 = (__temp2 = value, (__temp2 == NULL ? NULL : g_object_ref (__temp2))), (self->priv->_literal == NULL ? NULL : (self->priv->_literal = (g_object_unref (self->priv->_literal), NULL))), __temp3);
}


static void vala_literal_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaLiteralExpression * self;
	self = VALA_LITERAL_EXPRESSION (object);
	switch (property_id) {
		case VALA_LITERAL_EXPRESSION_LITERAL:
		g_value_set_object (value, vala_literal_expression_get_literal (self));
		break;
	}
}


static void vala_literal_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaLiteralExpression * self;
	self = VALA_LITERAL_EXPRESSION (object);
	switch (property_id) {
		case VALA_LITERAL_EXPRESSION_LITERAL:
		vala_literal_expression_set_literal (self, g_value_get_object (value));
		break;
	}
}


static void vala_literal_expression_class_init (ValaLiteralExpressionClass * klass)
{
	vala_literal_expression_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaLiteralExpressionPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_literal_expression_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_literal_expression_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_literal_expression_dispose;
	VALA_CODE_NODE_CLASS (klass)->accept = vala_literal_expression_real_accept;
	VALA_CODE_NODE_CLASS (klass)->to_string = vala_literal_expression_real_to_string;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_LITERAL_EXPRESSION_LITERAL, g_param_spec_object ("literal", "foo", "bar", VALA_TYPE_LITERAL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
}


static void vala_literal_expression_init (ValaLiteralExpression * self)
{
	self->priv = VALA_LITERAL_EXPRESSION_GET_PRIVATE (self);
}


static void vala_literal_expression_dispose (GObject * obj)
{
	ValaLiteralExpression * self;
	ValaLiteralExpressionClass * klass;
	GObjectClass * parent_class;
	self = VALA_LITERAL_EXPRESSION (obj);
	(self->priv->_literal == NULL ? NULL : (self->priv->_literal = (g_object_unref (self->priv->_literal), NULL)));
	klass = VALA_LITERAL_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_LITERAL_EXPRESSION));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	parent_class->dispose (obj);
}


GType vala_literal_expression_get_type ()
{
	static GType vala_literal_expression_type_id = 0;
	if (G_UNLIKELY (vala_literal_expression_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaLiteralExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_literal_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaLiteralExpression), 0, (GInstanceInitFunc) vala_literal_expression_init };
		vala_literal_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaLiteralExpression", &g_define_type_info, 0);
	}
	return vala_literal_expression_type_id;
}

==> vala-0.1.2.tar.bz2: vala-0.1.2/vala/valaliteralexpression.c <==
/* valaliteralexpression.vala
 *
 * Copyright (C) 2006-2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include "valaliteralexpression.h"
#include <vala/valaliteral.h>
#include <vala/valasourcereference.h>
#include <vala/valaliteralexpression.h>
#include <vala/valacodevisitor.h>

struct _ValaLiteralExpressionPrivate {
	ValaLiteral* _literal;
};
#define VALA_LITERAL_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_LITERAL_EXPRESSION, ValaLiteralExpressionPrivate))
enum  {
	VALA_LITERAL_EXPRESSION_DUMMY_PROPERTY,
	VALA_LITERAL_EXPRESSION_LITERAL
};
static void vala_literal_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
static char* vala_literal_expression_real_to_string (ValaCodeNode* base);
static gpointer vala_literal_expression_parent_class = NULL;
static void vala_literal_expression_dispose (GObject * obj);


/**
 * Creates a new literal expression.
 *
 * @param literal a literal
 * @param source  reference to source code
 * @return        newly created literal expression
 */
ValaLiteralExpression* vala_literal_expression_new (ValaLiteral* _literal, ValaSourceReference* source)
{
	GParameter * __params;
	GParameter * __params_it;
	ValaLiteralExpression * self;
	g_return_val_if_fail (VALA_IS_LITERAL (_literal), NULL);
	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
	__params = g_new0 (GParameter, 1);
	__params_it = __params;
	(__params_it->name = "literal", g_value_init (&__params_it->value, VALA_TYPE_LITERAL), g_value_set_object (&__params_it->value, _literal), __params_it++);
	self = g_object_newv (VALA_TYPE_LITERAL_EXPRESSION, __params_it - __params, __params);
	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
	while (__params_it > __params) {
		--__params_it;
		g_value_unset (&__params_it->value);
	}
	g_free (__params);
	return self;
}


static void vala_literal_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
{
	ValaLiteralExpression * self;
	self = ((ValaLiteralExpression*) base);
	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
	vala_code_node_accept (VALA_CODE_NODE (vala_literal_expression_get_literal (self)), visitor);
	vala_code_visitor_visit_literal_expression (visitor, self);
}


static char* vala_literal_expression_real_to_string (ValaCodeNode* base)
{
	ValaLiteralExpression * self;
	self = ((ValaLiteralExpression*) base);
	return vala_code_node_to_string (VALA_CODE_NODE (vala_literal_expression_get_literal (self)));
}


ValaLiteral* vala_literal_expression_get_literal (ValaLiteralExpression* self)
{
	g_return_val_if_fail (VALA_IS_LITERAL_EXPRESSION (self), NULL);
	return self->priv->_literal;
}


void vala_literal_expression_set_literal (ValaLiteralExpression* self, ValaLiteral* value)
{
	ValaLiteral* __temp3;
	ValaLiteral* __temp2;
	g_return_if_fail (VALA_IS_LITERAL_EXPRESSION (self));
	__temp3 = NULL;
	__temp2 = NULL;
	self->priv->_literal = (__temp3 = (__temp2 = value, (__temp2 == NULL ? NULL : g_object_ref (__temp2))), (self->priv->_literal == NULL ? NULL : (self->priv->_literal = (g_object_unref (self->priv->_literal), NULL))), __temp3);
}


static void vala_literal_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaLiteralExpression * self;
	self = VALA_LITERAL_EXPRESSION (object);
	switch (property_id) {
		case VALA_LITERAL_EXPRESSION_LITERAL:
		g_value_set_object (value, vala_literal_expression_get_literal (self));
		break;
	}
}


static void vala_literal_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaLiteralExpression * self;
	self = VALA_LITERAL_EXPRESSION (object);
	switch (property_id) {
		case VALA_LITERAL_EXPRESSION_LITERAL:
		vala_literal_expression_set_literal (self, g_value_get_object (value));
		break;
	}
}


static void vala_literal_expression_class_init (ValaLiteralExpressionClass * klass)
{
	vala_literal_expression_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaLiteralExpressionPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_literal_expression_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_literal_expression_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_literal_expression_dispose;
	VALA_CODE_NODE_CLASS (klass)->accept = vala_literal_expression_real_accept;
	VALA_CODE_NODE_CLASS (klass)->to_string = vala_literal_expression_real_to_string;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_LITERAL_EXPRESSION_LITERAL, g_param_spec_object ("literal", "foo", "bar", VALA_TYPE_LITERAL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
}


static void vala_literal_expression_init (ValaLiteralExpression * self)
{
	self->priv = VALA_LITERAL_EXPRESSION_GET_PRIVATE (self);
}


static void vala_literal_expression_dispose (GObject * obj)
{
	ValaLiteralExpression * self;
	ValaLiteralExpressionClass * klass;
	GObjectClass * parent_class;
	self = VALA_LITERAL_EXPRESSION (obj);
	(self->priv->_literal == NULL ? NULL : (self->priv->_literal = (g_object_unref (self->priv->_literal), NULL)));
	klass = VALA_LITERAL_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_LITERAL_EXPRESSION));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	parent_class->dispose (obj);
}


GType vala_literal_expression_get_type (void)
{
	static GType vala_literal_expression_type_id = 0;
	if (G_UNLIKELY (vala_literal_expression_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaLiteralExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_literal_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaLiteralExpression), 0, (GInstanceInitFunc) vala_literal_expression_init };
		vala_literal_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaLiteralExpression", &g_define_type_info, 0);
	}
	return vala_literal_expression_type_id;
}
